function [info] = CURexp(dataset,maxIter,lambda_row,lambda_col,accelerate,initMaxProxIter,initMinProxGap,gapSchedule,gapParam,initialL,thetaUpdate)

optTol = 1e-8;

%% Check to see if result file exists
resultDir = sprintf('CUR_results/%s_%d_%f_%f',dataset,maxIter,lambda_row,lambda_col);
if ~exist(resultDir,'dir')
	mkdir(resultDir);
end
resultFile = sprintf('%s/%f_%d_%f_%s_%f_%f_%d.mat',resultDir,accelerate,initMaxProxIter,initMinProxGap,gapSchedule,gapParam,initialL,thetaUpdate);
if exist(resultFile)
	fprintf('File Exists\n');
	load(resultFile);
	return
end

%% Load data
load(dataset);
data = data(:,2:end);
W    = data - mean( data(:) );
W    = W / norm(W,'fro');
[n,p] = size(W);

%% Initialize
X = zeros(p,n);
Y = zeros(p,n);
L = initialL;
%lambda_col = lambda_col*sqrt(p/n); % Roughly put rows and columns on same scale

%% Define Objective Function and Prox
g = @(X)(1/2)*norm(W-W*X*W,'fro')^2;
gp = @(X)-W'*(W-W*X*W)*W';
h = @(X)lambda_row*sum(sqrt(sum(X'.^2))) + lambda_col*sum(sqrt(sum(X.^2)));
prox = @(X,L,proxIter,proxGap)CUR_prox(X,L,lambda_row,lambda_col,proxIter,proxGap);

%% Run proximal-gradient method
gX = g(X);
f = gX+h(X);
gY = gX;
fY = f;
info = [f 0 0];

if initMinProxGap == -1
	initMinProxGap = norm(gp(X));
end

k = 1;
theta = 1;
maxProxIter = initMaxProxIter;
minProxGap = initMinProxGap;
while 1
	X_old = X;
	
	% Update duality gap
	switch gapSchedule
		case 'poly' % Error that decreases like 1/k
			if initMinProxGap == 0 % Try to estimate required duality based on first iteration
				if k == 1
					maxProxIter = 1;
				elseif k == 2
					maxProxIter = initMaxProxIter;
					initMinProxGap = proxGap;
				end
			end
			minProxGap = initMinProxGap/k^gapParam;
		case 'exp'
			minProxGap = initMinProxGap*gapParam^k;
	end
	
		% Compute proximal gradient step
		gpY = gp(Y);
		[X,proxIters,proxGap] = prox(Y - (1/L)*gpY,L,maxProxIter,minProxGap);
		gX = g(X);
		f = gX+h(X);
		fprintf('k = %d, proxIters = %d, proxGap = %.10f, f = %.10f\n',k,proxIters,proxGap,f);
		info(end+1,:) = [f proxIters proxGap];
		
		% Backtrack if Lipschitz inequality not satisfied
		while gX > gY + gpY(:)'*(X(:)-Y(:)) + (L/2)*sum((X(:)-Y(:)).^2)
			fprintf('Lipschitz estimate too small, increasing...\n');
			L = L*2;
			
			[X,proxIters,proxGap] = prox(Y - (1/L)*gpY,L,maxProxIter,minProxGap);
			gX = g(X);
			f = gX+h(X);
			fprintf('k = %d, proxIters = %d, proxGap = %.10f, f = %.10f\n',k,proxIters,proxGap,f);
			info(end+1,:) = [f proxIters proxGap];
			
			if sum(info(:,2)) >= maxIter
				save(resultFile,'info');
				return;
			end
		end
	
	
	% Update theta
	if accelerate
		if thetaUpdate == 0
			theta_new = 2/(k+2); %Y = X + (k-1)/(k+2)*(X-X_old);
		else
			theta_new = (sqrt(theta^4 + 4*theta^2)-theta^2)/2;
		end
	end
	
	% Compute Y
	if accelerate
		Y = X + theta_new*(1/theta -1)*(X-X_old);
		theta = theta_new;
		gY = g(Y);
		fY = gY+h(Y);
	else
		Y = X;
		gY = gX;
		fY = f;
	end
		
	if sum(info(:,2)) >= maxIter
		break;
	end
	k = k + 1;
end
save(resultFile,'info');
